/*  -*- Mode: C; tab-width: 4 -*-
 *
 * $Id$
 *
 * Copyright (c) 2009-2012 Personal Space Technologies, Inc.
 * Falckstraat 53 hs, NL-1017 VV, Amsterdam, the Netherlands.
 * All rights reserved.
 *
 * This software is the confidential and proprietary information of Personal
 * Space Technologies, Inc. ("Confidential Information").  You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered into
 * with Personal Space Technologies.
 */      

#include <stdio.h>
#include <math.h>
#include <stdlib.h>

#include "pstapi.h"

#ifdef WIN32
#define WIN32_LEAN_AND_MEAN

#include <windows.h>

long napawhile(unsigned int usecs)
{
    Sleep((DWORD) (usecs/1000.0));
    return 1;
}

#else

#include <sys/time.h>
#include <time.h>

long napawhile(unsigned int usecs)
{
#ifdef __APPLE__
	struct timeval x;
	x.tv_sec = (int) (usecs / 1000000);
	x.tv_usec = (int) (usecs % 1000000);
	return select(0, NULL, NULL, NULL, &x);
#else
	struct timespec x;
	x.tv_sec = (int) (usecs / 1000000);
	x.tv_nsec = (int) ((usecs % 1000000) * 1000);
	return (nanosleep(&x,NULL));
#endif
}
#endif

void Shutdown()
{
    pst_disconnect();
    exit(0);
}

#ifdef WIN32
BOOL WINAPI Handler (DWORD CntrlEvent)
{
     Shutdown();
     return TRUE;
}
#else
#include <sys/signal.h>
void SigHandler(int e)
{
    Shutdown();
}
#endif

int main (int ac, char **av)
{
    int i,j;
    struct PSTSensor sensor;
    struct PSTPoint point;

#ifdef WIN32
    SetConsoleCtrlHandler (Handler, TRUE);
#else
    signal(SIGINT, SigHandler);
#endif

    if (!pst_connect())
        exit (1);

    while (1)
    {
        while (pst_get_sensor(&sensor))
        {
            printf("SENSOR name = %s, id = %d\n", sensor.name, sensor.id);

            for (i=0; i<4; ++i)
            {
                for (j=0; j<4; ++j)
                {
                    printf("%.2f ", sensor.pose[i*4+j]);
                }
                printf("\n");
            }

            printf("\n");
        }

        while (pst_get_point(&point))
        {
            printf("POINT id = %d\n", point.id);

            for (i=0; i<3; ++i)
                printf("%.2f ", point.pos[i]);

            printf("\n");
        }

        napawhile(1000);
    }

    pst_disconnect();

    return 0;
}

