/*  -*- Mode: C; tab-width: 4 -*-
 *
 * $Id$
 *
 * Copyright (c) 2009-2012 Personal Space Technologies, Inc.
 * Falckstraat 53 hs, NL-1017 VV, Amsterdam, the Netherlands.
 * All rights reserved.
 *
 * This software is the confidential and proprietary information of Personal
 * Space Technologies, Inc. ("Confidential Information").  You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered into
 * with Personal Space Technologies.
 */      

#ifndef PSTLIB_H
#define PSTLIB_H

#if !defined PST_STATIC && (defined(_WIN32) || defined(_MSC_VER) || defined(__MWERKS__) || defined(__BORLANDC__))
#    ifdef PST_LIBRARY
#      define PST_EXPORT	__declspec(dllexport)
#    else
#      define PST_EXPORT	__declspec(dllimport)
#      pragma comment(lib, "pst.lib")
#    endif 
#else
#    define PST_EXPORT
#endif

#define PST_MAXSENSORS 100
#define PST_MAXPOINTS  100

/**
 * Holds an estimated device pose.
 */
struct PSTSensor
{
        char    name[80];       /**< Device name */
        int     id;             /**< Device identifier (for other tracking interfaces */
        float   pose[16];       /**< Device pose estimate as row-major matrix */
        double  timestamp;      /**< Time the data was recorded */
};

/**
 * Hold an estimated 3D marker location.
 */
struct PSTPoint
{
    int     id;             /**< Marker identifier */
    float   pos[3];         /**< Estimated marker location */
    double  timestamp;      /**< Time the data was recorded */
};

#ifdef __cplusplus
extern "C" {
#endif

PST_EXPORT int pst_get_connection_state(int* state);

PST_EXPORT int pst_connect();
PST_EXPORT int pst_disconnect();

PST_EXPORT int pst_sensor_changed();
PST_EXPORT int pst_sensor_changed_by_id(int id);
PST_EXPORT int pst_get_sensor (struct PSTSensor* sensor);
PST_EXPORT int pst_get_sensor_by_id(int id, struct PSTSensor* sensor);

PST_EXPORT int pst_point_changed();
PST_EXPORT int pst_get_point (struct PSTPoint* point);

#ifdef __cplusplus
}
#endif

#endif
